@@ -1,6 +1,7 @@
 from benedict.exceptions import ExtrasRequireModuleNotFoundError
 
 __all__ = [
+    "require_html",
     "require_parse",
     "require_s3",
     "require_toml",
@@ -15,6 +16,10 @@ def _require_optional_dependencies(*, target, installed):
         raise ExtrasRequireModuleNotFoundError(target=target)
 
 
+def require_html(*, installed):
+    _require_optional_dependencies(target="html", installed=installed)
+
+
 def require_parse(*, installed):
     _require_optional_dependencies(target="parse", installed=installed)
 
