@@ -2,7 +2,9 @@ import re
 
 from benedict.serializers.abstract import AbstractSerializer
 from benedict.serializers.base64 import Base64Serializer
+from benedict.serializers.cli import CLISerializer
 from benedict.serializers.csv import CSVSerializer
+from benedict.serializers.html import HTMLSerializer
 from benedict.serializers.ini import INISerializer
 from benedict.serializers.json import JSONSerializer
 from benedict.serializers.pickle import PickleSerializer
@@ -16,7 +18,9 @@ from benedict.serializers.yaml import YAMLSerializer
 __all__ = [
     "AbstractSerializer",
     "Base64Serializer",
+    "CLISerializer",
     "CSVSerializer",
+    "HTMLSerializer",
     "INISerializer",
     "JSONSerializer",
     "PickleSerializer",
@@ -29,7 +33,9 @@ __all__ = [
 ]
 
 _BASE64_SERIALIZER = Base64Serializer()
+_CLI_SERIALIZER = CLISerializer()
 _CSV_SERIALIZER = CSVSerializer()
+_HTML_SERIALIZER = HTMLSerializer()
 _INI_SERIALIZER = INISerializer()
 _JSON_SERIALIZER = JSONSerializer()
 _PICKLE_SERIALIZER = PickleSerializer()
@@ -42,7 +48,9 @@ _YAML_SERIALIZER = YAMLSerializer()
 
 _SERIALIZERS_LIST = [
     _BASE64_SERIALIZER,
+    _CLI_SERIALIZER,
     _CSV_SERIALIZER,
+    _HTML_SERIALIZER,
     _INI_SERIALIZER,
     _JSON_SERIALIZER,
     _PICKLE_SERIALIZER,
